@@ -58,7 +58,7 @@ from .rst import LanguageFeature
 from .rst import RstLanguageServer
 from .symbols import SymbolVisitor
 
-__version__ = "0.15.0"
+__version__ = "0.16.0"
 
 __all__ = [
     "CompletionContext",
@@ -248,12 +248,13 @@ def _configure_lsp_methods(server: RstLanguageServer) -> RstLanguageServer:
                             location=location,
                             match=match,
                             position=pos,
+                            config=ls.user_config.server.completion,
                             capabilities=ls.client_capabilities,
                         )
                         ls.logger.debug("Completion context: %s", context)
 
                         for item in feature.complete(context):
-                            item.data = {"source_feature": name, **(item.data or {})}
+                            item.data = {"source_feature": name, **(item.data or {})}  # type: ignore
                             items.append(item)
 
         return CompletionList(is_incomplete=False, items=items)
@@ -264,7 +265,7 @@ def _configure_lsp_methods(server: RstLanguageServer) -> RstLanguageServer:
     def on_completion_resolve(
         ls: RstLanguageServer, item: CompletionItem
     ) -> CompletionItem:
-        source = (item.data or {}).get("source_feature", "")
+        source = (item.data or {}).get("source_feature", "")  # type: ignore
         feature = ls.get_feature(source)
 
         if not feature:
